@@ -113,11 +113,10 @@ use std::{u8, usize};
 use typenum::{NonZero, Quot, Sub1, Sum, Unsigned, U16, U32, U64, U8};
 
 type MutBlocks<'a, B> = slice::IterMut<'a, B>;
-type StorageLen<NBits, B> = Quot<Sub1<Sum<NBits, BitsInOut<B>>>, BitsInOut<B>>;
-type BlocksNum<NBits, B> =
-    <<<NBits as Add<<B as BitsIn>::Output>>::Output as Sub<typenum::B1>>::Output as Div<
-        <B as BitsIn>::Output,
-    >>::Output;
+pub type StorageLen<NBits, B> = Quot<Sub1<Sum<NBits, BitsInOut<B>>>, BitsInOut<B>>;
+pub type BlocksNum<NBits, B> = <<<NBits as Add<<B as BitsIn>::Output>>::Output as Sub<
+    typenum::B1,
+>>::Output as Div<<B as BitsIn>::Output>>::Output;
 
 use std::ops::*;
 
